# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/suggestion/suggestion/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/suggestion/suggestion/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Suggestion\\Suggestion\\": "packages/suggestion/suggestion/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Suggestion\Suggestion\Providers\SuggestionServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Suggestion'  => Suggestion\Suggestion\Facades\Suggestion::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Suggestion\\SuggestionTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Suggestion\Suggestion\Providers\SuggestionServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Suggestion\Suggestion\Providers\SuggestionServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Suggestion\Suggestion\Providers\SuggestionServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/suggestion/{modulename}

**User**

    http://path-to-route-folder/user/suggestion/{modulename}

**Public**

    http://path-to-route-folder/suggestions


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/suggestion/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/suggestion/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/suggestion/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/suggestion/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/suggestion/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/suggestion/{modulename}/{slug}
    METHOD: GET