<?php

namespace Suggestion\Suggestion\Providers;

use Illuminate\Support\ServiceProvider;

class SuggestionServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'suggestion');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'suggestion');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerSuggestion();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerSuggestion()
    {
        $this->app->bind('suggestion', function($app) {
            return new Suggestion($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Suggestion', 'Lavalite\Suggestion\Facades\Suggestion');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('suggestion.suggestion', function ($app) {
            return $this->app->make('Suggestion\Suggestion\Suggestion');
        });

                // Bind Suggestions to repository
        $this->app->bind(
            'Suggestion\Suggestion\Interfaces\SuggestionsRepositoryInterface',
            \Suggestion\Suggestion\Repositories\Eloquent\SuggestionsRepository::class
        );

        $this->app->register(\Suggestion\Suggestion\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Suggestion\Suggestion\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and suggestion's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'suggestion.suggestion'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeSuggestion::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['suggestion.suggestion'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('suggestion/suggestion.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/suggestion')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/suggestion')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
